==> confluence-software-blueprints-5.0.0-sources.jar: com/atlassian/confluence/plugins/requirements/RequirementsContextProvider.java <==
package com.atlassian.confluence.plugins.requirements;

import com.atlassian.confluence.plugins.SoftwareBlueprintsContextProviderHelper;
import com.atlassian.confluence.plugins.common.event.SoftwareBPAnalyticEventUtils;
import com.atlassian.confluence.plugins.createcontent.api.contextproviders.AbstractBlueprintContextProvider;
import com.atlassian.confluence.plugins.createcontent.api.contextproviders.BlueprintContext;
import com.atlassian.confluence.renderer.template.TemplateRenderer;
import com.atlassian.confluence.user.AuthenticatedUserThreadLocal;

import java.util.HashMap;
import java.util.Map;

public class RequirementsContextProvider extends AbstractBlueprintContextProvider {
    private static final String DOCUMENT_OWNER = "documentOwner";

    private static final String TEMPLATE_PROVIDER_PLUGIN_KEY =
            "com.atlassian.confluence.plugins.confluence-software-blueprints:requirements-resources";

    private static final String MENTION_TEMPLATE_NAME = "Confluence.Templates.Requirements.userMention.soy";

    private static final String USERNAME_KEY = "username";

    private TemplateRenderer templateRenderer;
    private final SoftwareBlueprintsContextProviderHelper helper;

    public RequirementsContextProvider(TemplateRenderer templateRenderer, SoftwareBlueprintsContextProviderHelper helper) {
        this.templateRenderer = templateRenderer;
        this.helper = helper;
    }

    @Override
    protected BlueprintContext updateBlueprintContext(BlueprintContext context) {
        String username = AuthenticatedUserThreadLocal.getUsername();
        StringBuilder userMention = new StringBuilder();
        Map<String, Object> contextMap = new HashMap<String, Object>();

        if (username != null) {
            contextMap.put(USERNAME_KEY, username);
        }

        templateRenderer.renderTo(userMention, TEMPLATE_PROVIDER_PLUGIN_KEY, MENTION_TEMPLATE_NAME, contextMap);
        context.put(DOCUMENT_OWNER, userMention.toString());

        //analytic for create requirement
        helper.publishAnalyticEvent(SoftwareBPAnalyticEventUtils.REQUIREMENT_CREATE_EVENT_NAME);

        return context;
    }
}

==> confluence-software-blueprints-6.0.7-sources.jar: com/atlassian/confluence/plugins/requirements/RequirementsContextProvider.java <==
package com.atlassian.confluence.plugins.requirements;

import com.atlassian.confluence.plugins.SoftwareBlueprintsContextProviderHelper;
import com.atlassian.confluence.plugins.common.event.SoftwareBPAnalyticEventUtils;
import com.atlassian.confluence.plugins.createcontent.api.contextproviders.AbstractBlueprintContextProvider;
import com.atlassian.confluence.plugins.createcontent.api.contextproviders.BlueprintContext;
import com.atlassian.confluence.renderer.template.TemplateRenderer;
import com.atlassian.confluence.user.AuthenticatedUserThreadLocal;
import com.atlassian.confluence.user.ConfluenceUser;

import java.util.HashMap;
import java.util.Map;

/**
 * @since 1.2.2
 */
public class RequirementsContextProvider extends AbstractBlueprintContextProvider {
    private static final String DOCUMENT_OWNER = "documentOwner";

    private static final String TEMPLATE_PROVIDER_PLUGIN_KEY =
            "com.atlassian.confluence.plugins.confluence-software-blueprints:requirements-resources";

    private static final String MENTION_TEMPLATE_NAME = "Confluence.Templates.Requirements.userMention.soy";

    private static final String OWNER_KEY = "userKey";

    private TemplateRenderer templateRenderer;
    private final SoftwareBlueprintsContextProviderHelper helper;

    public RequirementsContextProvider(TemplateRenderer templateRenderer, SoftwareBlueprintsContextProviderHelper helper) {
        this.templateRenderer = templateRenderer;
        this.helper = helper;
    }

    @Override
    protected BlueprintContext updateBlueprintContext(BlueprintContext context) {
        ConfluenceUser user = AuthenticatedUserThreadLocal.get();
        StringBuilder userMention = new StringBuilder();
        Map<String, Object> contextMap = new HashMap<>();

        if (user != null) {
            contextMap.put(OWNER_KEY, user.getKey().getStringValue());
        }

        templateRenderer.renderTo(userMention, TEMPLATE_PROVIDER_PLUGIN_KEY, MENTION_TEMPLATE_NAME, contextMap);
        context.put(DOCUMENT_OWNER, userMention.toString());

        //analytic for create requirement
        helper.publishAnalyticEvent(SoftwareBPAnalyticEventUtils.REQUIREMENT_CREATE_EVENT_NAME);

        return context;
    }
}
